import { useEffect } from "react";
import { useAppSelector } from "@src/infrastructure/store";
import { todosSelectors } from "@src/infrastructure/state/todo";
import { todosApi } from "@src/infrastructure/apis/todosApi";
import { Priorities, Todo } from "@src/core/entities/todo";
import { nanoid } from "@reduxjs/toolkit";

export const useSelectInboxTodos = () => {
  const todos = useAppSelector(todosSelectors.selectAll);

  return {
    loading: false,
    todos,
  };
};

export const useCreateTodo = () => {
  const [createTodo, { isLoading }] = todosApi.useCreateTodoMutation();

  return {
    createTodo: (
      todoName: string,
      description: string,
      project?: string,
      priority?: Priorities
    ) => {
      createTodo({
        id: nanoid(),
        created: 0,
        status: false,
        title: todoName,
        project,
        description,
        priority,
      });
    },
  };
};

export const useSelectTodo = (
  todoId: string
): { todo: Todo | undefined; isLoading: boolean } => {
  const { data, isLoading } = todosApi.useGetTodoByIdQuery(todoId);

  useEffect(() => {}, []);

  return {
    todo: data,
    isLoading: isLoading,
  };
};

export const useUpdateTodo = () => {
  const [replaceTodo, { isLoading }] = todosApi.useReplaceTodoMutation();

  return {
    updateTodo: (todo: Todo) => {
      replaceTodo(todo);
    },
  };
};
